@@ -18,4 +18,10 @@
 #
 #############################################################################
 
+from . import version
 from .version import __version__
+from . import iii_v
+from .iii_v import *
+
+__all__ = ['__version__']
+__all__ += iii_v.__all__
