@@ -58,20 +58,30 @@ class Quaternary(AlloyBase):
         temperature, T, in Kelvin (default: 300 K).
         '''
         if self is not None:
-            T = self._get_T(kwargs)
-            return min(self.Eg_Gamma(T=T), self.Eg_X(T=T), self.Eg_L(T=T))
+            return min(self.Eg_Gamma(**kwargs), self.Eg_X(**kwargs),
+                       self.Eg_L(**kwargs))
         else:
-            x = cls._get_x(kwargs)
-            y = cls._get_y(kwargs)
-            T = cls._get_T(kwargs)
-            return min(cls.Eg_Gamma(x=x, y=y, T=T), cls.Eg_X(x=x, y=y, T=T),
-                       cls.Eg_L(x=x, y=y, T=T))
+            return min(cls.Eg_Gamma(**kwargs), cls.Eg_X(**kwargs),
+                       cls.Eg_L(**kwargs))
 
     def __eq__(self, other):
         return (type(self) == type(other) and
                 self._x == other._x and
                 self._y == other._y)
 
+    @classmethod
+    def _get_bowing(cls, param):
+        if hasattr(cls, '_bowing_%s' % param):
+            # bowing parameters exists - use it
+            C = getattr(cls, '_bowing_%s' % param)
+            if hasattr(C, '__call__'):
+                # it's trying to mix the ternary bowing parameters
+                return None
+            else:
+                return C
+        else:
+            return None
+
 
 class Quaternary1or2(Quaternary):
     '''
@@ -119,14 +129,17 @@ class Quaternary1or2(Quaternary):
             y = cls._get_y(kwargs)
             z = cls._get_z(kwargs)
             x = round(1 - y - z, 6)
-        elif 'a' in kwargs and 'T' in kwargs and cls._has_x(kwargs):
-            x, y, z = cls._lattice_match(kwargs['a'], kwargs['T'],
+        elif 'a' in kwargs and cls._has_x(kwargs):
+            T = kwargs.get('T', 300)
+            x, y, z = cls._lattice_match(kwargs['a'], T,
                                          x=cls._get_x(kwargs))
-        elif 'a' in kwargs and 'T' in kwargs and cls._has_y(kwargs):
-            x, y, z = cls._lattice_match(kwargs['a'], kwargs['T'],
+        elif 'a' in kwargs and cls._has_y(kwargs):
+            T = kwargs.get('T', 300)
+            x, y, z = cls._lattice_match(kwargs['a'], T,
                                          y=cls._get_y(kwargs))
-        elif 'a' in kwargs and 'T' in kwargs and cls._has_z(kwargs):
-            x, y, z = cls._lattice_match(kwargs['a'], kwargs['T'],
+        elif 'a' in kwargs and cls._has_z(kwargs):
+            T = kwargs.get('T', 300)
+            x, y, z = cls._lattice_match(kwargs['a'], T,
                                          z=cls._get_z(kwargs))
         else:
             raise TypeError(
@@ -211,18 +224,30 @@ class Quaternary1or2(Quaternary):
             t13 = vals[1](**new_kwargs)
             new_kwargs['x'] = v
             t23 = vals[2](**new_kwargs)
+
+        # Calculate the weights, for use in the next step
         weight12 = x * y
         weight13 = x * z
         weight23 = y * z
+        num = weight12 * t12 + weight13 * t13 + weight23 * t23
         denom = weight12 + weight13 + weight23
+        # handle these cases explicitly, so there's no divide by zero
         if denom == 0.:
-            # handle this explicitly, so there's no divide by zero
             if x == 0.:
                 return t23
             else:
                 return t13
+
+        # Check if there are bowing parameters provided
+        C = cls._get_bowing(param)
+        if C is not None:
+            # a bowing parameter exists - use it
+            # Note: this is an experimental mixing formula for
+            # adding additional quaternary-induced bowing
+            return num / denom - C * x * (1-x) * y * (1-y) * z * (1-z)
         else:
-            num = weight12 * t12 + weight13 * t13 + weight23 * t23
+            # otherwise, use a weighted average of the ternary bowing
+            # parameters
             return num / denom
 
 
@@ -334,9 +359,9 @@ class Quaternary1(Quaternary1or2):
                 "\n    - ('x' or '{B}') and ('y' or '{C}')"
                 "\n    - ('x' or '{B}') and ('z' or '{D}')"
                 "\n    - ('y' or '{C}') and ('z' or '{D}')"
-                "\n    - 'a' and 'T' and ('x' or '{B}')"
-                "\n    - 'a' and 'T' and ('y' or '{C}')"
-                "\n    - 'a' and 'T' and ('z' or '{D}')"
+                "\n    - 'a' and ('x' or '{B}')"
+                "\n    - 'a' and ('y' or '{C}')"
+                "\n    - 'a' and ('z' or '{D}')"
                             "".format(A=cls.elements[0], B=cls.elements[1],
                                       C=cls.elements[2], D=cls.elements[3]))
 
@@ -463,9 +488,9 @@ class Quaternary2(Quaternary1or2):
                 "\n    - ('x' or '{A}') and ('y' or '{B}')"
                 "\n    - ('x' or '{A}') and ('z' or '{C}')"
                 "\n    - ('y' or '{B}') and ('z' or '{C}')"
-                "\n    - 'a' and 'T' and ('x' or '{A}')"
-                "\n    - 'a' and 'T' and ('y' or '{B}')"
-                "\n    - 'a' and 'T' and ('z' or '{C}')"
+                "\n    - 'a' and ('x' or '{A}')"
+                "\n    - 'a' and ('y' or '{B}')"
+                "\n    - 'a' and ('z' or '{C}')"
                             "".format(A=cls.elements[0], B=cls.elements[1],
                                       C=cls.elements[2], D=cls.elements[3]))
 
@@ -599,14 +624,15 @@ class Quaternary3(Quaternary):
         if cls._has_x(kwargs) and cls._has_y(kwargs):
             x = cls._get_x(kwargs)
             y = cls._get_y(kwargs)
-        elif 'a' in kwargs and 'T' in kwargs and cls._has_x(kwargs):
-            x, y = cls._lattice_match(kwargs['a'], kwargs['T'],
+        elif 'a' in kwargs and cls._has_x(kwargs):
+            T = kwargs.get('T', 300)
+            x, y = cls._lattice_match(kwargs['a'], T,
                                       x=cls._get_x(kwargs))
-        elif 'a' in kwargs and 'T' in kwargs and cls._has_y(kwargs):
-            x, y = cls._lattice_match(kwargs['a'], kwargs['T'],
+        elif 'a' in kwargs and cls._has_y(kwargs):
+            T = kwargs.get('T', 300)
+            x, y = cls._lattice_match(kwargs['a'], T,
                                       y=cls._get_y(kwargs))
         else:
-            print kwargs, cls._has_x(kwargs), cls._has_y(kwargs)
             raise TypeError(
                 "Missing required key word argument.\n" + cls._get_usage())
         cls._validate_xy(x, y)
@@ -646,10 +672,10 @@ class Quaternary3(Quaternary):
 
     @classmethod
     def _get_usage(cls):
-        return ("The  supported kwarg combinations are as follows:"
+        return ("The supported kwargs combinations are as follows:"
                 "\n    - ('x', '{A}' or '{B}') and ('y', '{C}' or '{D}')"
-                "\n    - 'a' and 'T' and ('x', '{A}' or '{B}')"
-                "\n    - 'a' and 'T' and ('y', '{C}' or '{D}')"
+                "\n    - 'a' and ('x', '{A}' or '{B}')"
+                "\n    - 'a' and ('y', '{C}' or '{D}')"
                             "".format(A=cls.elements[0], B=cls.elements[1],
                                       C=cls.elements[2], D=cls.elements[3]))
 
@@ -670,35 +696,54 @@ class Quaternary3(Quaternary):
                 e.message += '. Ternary `%s`' % t.name
                 e.message += ' missing param `%s`' % param
                 raise e
+        # B1 = Q(0, 0) = BD = InSb
+        # B2 = Q(1, 0) = BC = InAs
+        # B3 = Q(1, 1) = AC = AlAs
+        # B4 = Q(0, 1) = AD = AlSb
+        # T12 = Q(x, 0) = ABD = AlInSb
+        # T23 = Q(1, y) = ACD = AlAsSb
+        # T43 = Q(x, 1) = ABC = AlInAs
+        # T14 = Q(0, y) = BCD = InAsSb
         if param[0] == '_':
             # assume it's a hard coded parameter if it starts with '_'
-            ABC = vals[0]
-            ABD = vals[1]
-            ACD = vals[2]
-            BCD = vals[3]
+            T43 = vals[0]
+            T12 = vals[1]
+            T23 = vals[2]
+            T14 = vals[3]
         else:
             # otherwise it's an accessor function
             new_kwargs = dict(kwargs)
-            new_kwargs['x'] = x
-            ABC = vals[0](**new_kwargs)
-            ABD = vals[1](**new_kwargs)
-            new_kwargs['x'] = y
-            ACD = vals[2](**new_kwargs)
-            BCD = vals[3](**new_kwargs)
+            new_kwargs.pop('x', None)
+            T43 = vals[0](x=x, **new_kwargs)
+            T12 = vals[1](x=x, **new_kwargs)
+            T23 = vals[2](x=y, **new_kwargs)
+            T14 = vals[3](x=y, **new_kwargs)
+
+        # handle these cases explicitly, so there's no divide by zero
+        if x == 0.:
+            return T14
+        elif x == 1.:
+            return T23
+        elif y == 0.:
+            return T12
+        elif y == 1.:
+            return T43
         xinv = 1. - x
         yinv = 1. - y
         xweight = x * xinv
         yweight = y * yinv
+        num = (xweight * (yinv * T12 + y * T43) + 
+               yweight * (xinv * T14 + x * T23))
         denom = xweight + yweight
-        if denom == 0.:
-            # handle this explicitly, so there's no divide by zero
-            if x == 0.:
-                return BCD
-            else:
-                return ACD
+
+        # Check if there are bowing parameters provided
+        C = cls._get_bowing(param)
+        if C is not None:
+            # a bowing parameter exists - use it
+            # Note: this is a new, experimental mixing formula for
+            # adding additional quaternary-induced bowing
+            return num / denom - C * xweight * yweight
         else:
-            num = (xweight * (y * ABC + yinv * ABD) +
-                   yweight * (x * ACD + xinv * BCD))
             return num / denom
 
     @classinstancemethod
